==> taxopedia-0.2.1-py3-none-any.whl: helpers/constants.py <==
RANK = [
    "Rank", "Common Name", "Domain", "Subdomain", "Realm", "Subrealm",
    "Hyperkingdom", "Superkingdom", "Kingdom", "Subkingdom", "Infrakingdom",
    "Parvkingdom", "Superphylum", "Phylum", "Subphylum", "Infraphylum",
    "Microphylum", "Superclass", "Class", "Subclass", "Infraclass",
    "Parvclass", "Superdivision", "Division", "Subdivision", "Infradivision",
    "Superlegion", "Legion", "Sublegion", "Infralegion", "Supercohort",
    "Cohort", "Subcohort", "Infracohort", "Gigaorder", "Magnorder",
    "Grandorder", "Mirorder", "Superorder", "Series", "Order", "Parvorder",
    "Nanorder", "Hypoorder", "Minorder", "Suborder", "Infraorder",
    "Parvorder", "Section", "Subsection", "Gigafamily", "Megafamily",
    "Grandfamily", "Hyperfamily", "Superfamily", "Epifamily", "Series",
    "Group", "Family", "Subfamily", "Infrafamily", "Supertribe", "Tribe",
    "Subtribe", "Infratribe", "Genus", "Subgenus", "Section", "Subsection",
    "Series", "Subseries", "Superspecies", "Species", "Subspecies",
    "Variety", "Subvariety", "Form", "Subform"
]

COLORS = {
    "reset": "\x1b[0m",
    "black": "\x1b[30m",
    "red": "\x1b[31m",
    "green": "\x1b[32m",
    "yellow": "\x1b[33m",
    "blue": "\x1b[34m",
    "magenta": "\x1b[35m",
    "cyan": "\x1b[36m",
    "white": "\x1b[37m",
    "br_black": "\x1b[90m",
    "br_red": "\x1b[91m",
    "br_green": "\x1b[92m",
    "br_yellow": "\x1b[93m",
    "br_blue": "\x1b[94m",
    "br_magenta": "\x1b[95m",
    "br_cyan": "\x1b[96m",
    "br_white": "\x1b[97m",
    "black_bg": "\x1b[40m",
    "red_bg": "\x1b[41m",
    "green_bg": "\x1b[42m",
    "yellow_bg": "\x1b[43m",
    "blue_bg": "\x1b[44m",
    "magenta_bg": "\x1b[45m",
    "cyan_bg": "\x1b[46m",
    "white_bg": "\x1b[47m",
    "br_black_bg": "\x1b[100m",
    "br_red_bg": "\x1b[101m",
    "br_green_bg": "\x1b[102m",
    "br_yellow_bg": "\x1b[103m",
    "br_blue_bg": "\x1b[104m",
    "br_magenta_bg": "\x1b[105m",
    "br_cyan_bg": "\x1b[106m",
    "br_white_bg": "\x1b[107m"
}

==> taxopedia-0.2.2-py3-none-any.whl: helpers/constants.py <==
RANK = [
    "Rank", "Common Name", "Domain", "Subdomain", "Realm", "Subrealm",
    "Hyperkingdom", "Superkingdom", "Kingdom", "Subkingdom", "Infrakingdom",
    "Parvkingdom", "Superphylum", "Phylum", "Subphylum", "Infraphylum",
    "Microphylum", "Superclass", "Class", "Subclass", "Infraclass",
    "Parvclass", "Superdivision", "Division", "Subdivision", "Infradivision",
    "Superlegion", "Legion", "Sublegion", "Infralegion", "Supercohort",
    "Cohort", "Subcohort", "Infracohort", "Gigaorder", "Magnorder",
    "Grandorder", "Mirorder", "Superorder", "Series", "Order", "Parvorder",
    "Nanorder", "Hypoorder", "Minorder", "Suborder", "Infraorder",
    "Parvorder", "Section", "Subsection", "Gigafamily", "Megafamily",
    "Grandfamily", "Hyperfamily", "Superfamily", "Epifamily", "Series",
    "Group", "Family", "Subfamily", "Infrafamily", "Supertribe", "Tribe",
    "Subtribe", "Infratribe", "Genus", "Subgenus", "Section", "Subsection",
    "Series", "Subseries", "Superspecies", "Species", "Subspecies",
    "Hybrid", "Variety", "Subvariety", "Form", "Subform"
]

COLORS = {
    "reset": "\x1b[0m",
    "black": "\x1b[30m",
    "red": "\x1b[31m",
    "green": "\x1b[32m",
    "yellow": "\x1b[33m",
    "blue": "\x1b[34m",
    "magenta": "\x1b[35m",
    "cyan": "\x1b[36m",
    "white": "\x1b[37m",
    "br_black": "\x1b[90m",
    "br_red": "\x1b[91m",
    "br_green": "\x1b[92m",
    "br_yellow": "\x1b[93m",
    "br_blue": "\x1b[94m",
    "br_magenta": "\x1b[95m",
    "br_cyan": "\x1b[96m",
    "br_white": "\x1b[97m",
    "black_bg": "\x1b[40m",
    "red_bg": "\x1b[41m",
    "green_bg": "\x1b[42m",
    "yellow_bg": "\x1b[43m",
    "blue_bg": "\x1b[44m",
    "magenta_bg": "\x1b[45m",
    "cyan_bg": "\x1b[46m",
    "white_bg": "\x1b[47m",
    "br_black_bg": "\x1b[100m",
    "br_red_bg": "\x1b[101m",
    "br_green_bg": "\x1b[102m",
    "br_yellow_bg": "\x1b[103m",
    "br_blue_bg": "\x1b[104m",
    "br_magenta_bg": "\x1b[105m",
    "br_cyan_bg": "\x1b[106m",
    "br_white_bg": "\x1b[107m"
}
